/*
**==============================================================================
**
** Microsoft Public License (Ms-PL)
** 
** This license governs use of the accompanying software. If you use the 
** software, you accept this license. If you do not accept the license, do not 
** use the software.
**
** 1. Definitions
** The terms "reproduce," "reproduction," "derivative works," and 
** "distribution" have the same meaning here as under U.S. copyright law.
** A "contribution" is the original software, or any additions or changes to 
** the software.
** A "contributor" is any person that distributes its contribution under this 
** license.
** "Licensed patents" are a contributor's patent claims that read directly on 
** its contribution.
**
** 2. Grant of Rights
** (A) Copyright Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free copyright license to reproduce its
** contribution, prepare derivative works of its contribution, and distribute 
** its contribution or any derivative works that you create.
** (B) Patent Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free license under its licensed patents
** to make, have made, use, sell, offer for sale, import, and/or otherwise 
** dispose of its contribution in the software or derivative works of the 
** contribution in the software.
**
** 3. Conditions and Limitations
** (A) No Trademark License- This license does not grant you rights to use any 
** contributors' name, logo, or trademarks.
** (B) If you bring a patent claim against any contributor over patents that 
** you claim are infringed by the software, your patent license from such 
** contributor to the software ends automatically.
** (C) If you distribute any portion of the software, you must retain all 
** copyright, patent, trademark, and attribution notices that are present in 
** the software.
** (D) If you distribute any portion of the software in source code form, you 
** may do so only under this license by including a complete copy of this 
** license with your distribution. If you distribute any portion of the 
** software in compiled or object code form, you may only do so under a license
** that complies with this license.
** (E) The software is licensed "as-is." You bear the risk of using it. The 
** contributors give no express warranties, guarantees or conditions. You may 
** have additional consumer rights under your local laws which this license 
** cannot change. To the extent permitted under your local laws, the 
** contributors exclude the implied warranties of merchantability, fitness for 
** a particular purpose and non-infringement.
**
**==============================================================================
*/
/**
    \file        

    \brief       Time primitives 
    
    \date        07-10-29 11:23:02

    < Optional detailed description of file purpose >
    
*/
/*----------------------------------------------------------------------------*/
#ifndef SCXTIME_PRIMITIVES_H
#define SCXTIME_PRIMITIVES_H

#include <scxcorelib/scxtime.h>

namespace SCXCoreLib {
    bool IsLeapYear(SCXCoreLib::scxyear year);
    unsigned DaysInMonth(SCXCoreLib::scxyear year, SCXCoreLib::scxmonth month);
    void CalculatePriorMonth(SCXCoreLib::scxyear &year, SCXCoreLib::scxmonth &month);
    void CalculateNextMonth(SCXCoreLib::scxyear &year, SCXCoreLib::scxmonth &month);
    void CalculatePriorDay(SCXCoreLib::scxyear &year, SCXCoreLib::scxmonth &month, SCXCoreLib::scxday &day);
    void CalculateNextDay(SCXCoreLib::scxyear &year, SCXCoreLib::scxmonth &month, SCXCoreLib::scxday &day);
    void CalculatePriorHour(SCXCoreLib::scxyear &year, SCXCoreLib::scxmonth &month, SCXCoreLib::scxday &day, SCXCoreLib::scxhour &hour);
    void CalculateNextHour(SCXCoreLib::scxyear &year, SCXCoreLib::scxmonth &month, SCXCoreLib::scxday &day, SCXCoreLib::scxhour &hour);
    void CalculatePriorMinute(SCXCoreLib::scxyear &year, SCXCoreLib::scxmonth &month, SCXCoreLib::scxday &day, SCXCoreLib::scxhour &hour, SCXCoreLib::scxminute &minute);
    void CalculateNextMinute(SCXCoreLib::scxyear &year, SCXCoreLib::scxmonth &month, SCXCoreLib::scxday &day, SCXCoreLib::scxhour &hour, SCXCoreLib::scxminute &minute);
    unsigned DaysInYear(SCXCoreLib::scxyear year);
    unsigned HoursInDay(SCXCoreLib::scxyear, SCXCoreLib::scxmonth, SCXCoreLib::scxday); 
    unsigned MinutesInDay(SCXCoreLib::scxyear, SCXCoreLib::scxmonth, SCXCoreLib::scxday);
    unsigned MinutesInPriorDay(SCXCoreLib::scxyear, SCXCoreLib::scxmonth, SCXCoreLib::scxday);
    unsigned DaysInPriorMonth(SCXCoreLib::scxyear, SCXCoreLib::scxmonth);
    unsigned HoursInMonth(SCXCoreLib::scxyear, SCXCoreLib::scxmonth);
    unsigned HoursInPriorMonth(SCXCoreLib::scxyear, SCXCoreLib::scxmonth);
    unsigned HoursInYear(SCXCoreLib::scxyear);
    unsigned HoursInPriorDay(SCXCoreLib::scxyear, SCXCoreLib::scxmonth, SCXCoreLib::scxday);
    unsigned MinutesInMonth(SCXCoreLib::scxyear, SCXCoreLib::scxmonth);
    unsigned MinutesInPriorMonth(SCXCoreLib::scxyear year, SCXCoreLib::scxmonth month);
    unsigned MinutesInYear(SCXCoreLib::scxyear);
    unsigned MinutesInHour(SCXCoreLib::scxyear, SCXCoreLib::scxmonth, SCXCoreLib::scxday, SCXCoreLib::scxhour);
    unsigned MinutesInPriorHour(SCXCoreLib::scxyear, SCXCoreLib::scxmonth, SCXCoreLib::scxday, SCXCoreLib::scxhour);
    unsigned MicrosecondsInMinute(SCXCoreLib::scxyear, SCXCoreLib::scxmonth, SCXCoreLib::scxday, SCXCoreLib::scxhour, SCXCoreLib::scxminute);
    scxulong MicrosecondsInHour(SCXCoreLib::scxyear, SCXCoreLib::scxmonth, SCXCoreLib::scxday, SCXCoreLib::scxhour);
    scxulong MicrosecondsInDay(SCXCoreLib::scxyear, SCXCoreLib::scxmonth, SCXCoreLib::scxday);
    scxulong MicrosecondsInMonth(SCXCoreLib::scxyear year, SCXCoreLib::scxmonth month);
    scxulong MicrosecondsInYear(SCXCoreLib::scxyear year);
    unsigned MicrosecondsInPriorMinute(SCXCoreLib::scxyear, SCXCoreLib::scxmonth, SCXCoreLib::scxday, SCXCoreLib::scxhour, SCXCoreLib::scxminute);
    scxulong MicrosecondsInPriorHour(SCXCoreLib::scxyear year, SCXCoreLib::scxmonth month, SCXCoreLib::scxday day, SCXCoreLib::scxhour hour);
    scxulong MicrosecondsInPriorDay(SCXCoreLib::scxyear year, SCXCoreLib::scxmonth month, SCXCoreLib::scxday day);
    scxulong MicrosecondsInPriorMonth(SCXCoreLib::scxyear year, SCXCoreLib::scxmonth month);   
}

#endif /* SCXTIME_PRIMITIVES_H */
/*----------------------------E-N-D---O-F---F-I-L-E---------------------------*/
