/*
**==============================================================================
**
** Microsoft Public License (Ms-PL)
** 
** This license governs use of the accompanying software. If you use the 
** software, you accept this license. If you do not accept the license, do not 
** use the software.
**
** 1. Definitions
** The terms "reproduce," "reproduction," "derivative works," and 
** "distribution" have the same meaning here as under U.S. copyright law.
** A "contribution" is the original software, or any additions or changes to 
** the software.
** A "contributor" is any person that distributes its contribution under this 
** license.
** "Licensed patents" are a contributor's patent claims that read directly on 
** its contribution.
**
** 2. Grant of Rights
** (A) Copyright Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free copyright license to reproduce its
** contribution, prepare derivative works of its contribution, and distribute 
** its contribution or any derivative works that you create.
** (B) Patent Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free license under its licensed patents
** to make, have made, use, sell, offer for sale, import, and/or otherwise 
** dispose of its contribution in the software or derivative works of the 
** contribution in the software.
**
** 3. Conditions and Limitations
** (A) No Trademark License- This license does not grant you rights to use any 
** contributors' name, logo, or trademarks.
** (B) If you bring a patent claim against any contributor over patents that 
** you claim are infringed by the software, your patent license from such 
** contributor to the software ends automatically.
** (C) If you distribute any portion of the software, you must retain all 
** copyright, patent, trademark, and attribution notices that are present in 
** the software.
** (D) If you distribute any portion of the software in source code form, you 
** may do so only under this license by including a complete copy of this 
** license with your distribution. If you distribute any portion of the 
** software in compiled or object code form, you may only do so under a license
** that complies with this license.
** (E) The software is licensed "as-is." You bear the risk of using it. The 
** contributors give no express warranties, guarantees or conditions. You may 
** have additional consumer rights under your local laws which this license 
** cannot change. To the extent permitted under your local laws, the 
** contributors exclude the implied warranties of merchantability, fitness for 
** a particular purpose and non-infringement.
**
**==============================================================================
*/
/**
    \file        

    \brief       Contains the definitions of log item class.

    \date        07-06-08 13:56:00
    
*/
/*----------------------------------------------------------------------------*/
#ifndef SCXLOGITEM_H
#define SCXLOGITEM_H

#include <scxcorelib/scxlog.h>
#include <scxcorelib/scxthread.h>
#include <scxcorelib/scxtime.h>
#include <string>

namespace SCXCoreLib
{
    /*----------------------------------------------------------------------------*/
    /**
        This is the data carrier for logs.
    
        Data carrier class for logging.

        This is how a log item is represented internally.

    */
    class SCXLogItem
    {
    public:
        SCXLogItem();
        SCXLogItem(const std::wstring& module,
                   SCXLogSeverity severity,
                   const std::wstring& message,
                   const SCXCodeLocation& location,
                   SCXCoreLib::SCXThreadId threadId);
        SCXLogItem(const SCXLogItem& o);
        virtual ~SCXLogItem();
	SCXLogItem& operator=(const SCXLogItem& o);
        
        const std::wstring& GetModule() const;
        SCXLogSeverity GetSeverity() const;
        const std::wstring& GetMessage() const;
        const SCXCodeLocation& GetLocation() const;
        SCXThreadId GetThreadId() const;
        const SCXCalendarTime& GetTimestamp() const;

        virtual const std::wstring DumpString() const;

    protected:
        std::wstring m_module;       //!< Module string.
        SCXLogSeverity m_severity;   //!< Severity of log item.
        std::wstring m_message;      //!< Original log message.
        SCXCodeLocation m_location;  //!< Code location where log occurred.
        SCXThreadId m_threadId;      //!< Thread id of originating thread.
        SCXCalendarTime m_timestamp; //!< Timestamp when log item was created.
    };
}

#endif /* SCXLOGITEM_H */
/*----------------------------E-N-D---O-F---F-I-L-E---------------------------*/
