/*
**==============================================================================
**
** Microsoft Public License (Ms-PL)
** 
** This license governs use of the accompanying software. If you use the 
** software, you accept this license. If you do not accept the license, do not 
** use the software.
**
** 1. Definitions
** The terms "reproduce," "reproduction," "derivative works," and 
** "distribution" have the same meaning here as under U.S. copyright law.
** A "contribution" is the original software, or any additions or changes to 
** the software.
** A "contributor" is any person that distributes its contribution under this 
** license.
** "Licensed patents" are a contributor's patent claims that read directly on 
** its contribution.
**
** 2. Grant of Rights
** (A) Copyright Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free copyright license to reproduce its
** contribution, prepare derivative works of its contribution, and distribute 
** its contribution or any derivative works that you create.
** (B) Patent Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free license under its licensed patents
** to make, have made, use, sell, offer for sale, import, and/or otherwise 
** dispose of its contribution in the software or derivative works of the 
** contribution in the software.
**
** 3. Conditions and Limitations
** (A) No Trademark License- This license does not grant you rights to use any 
** contributors' name, logo, or trademarks.
** (B) If you bring a patent claim against any contributor over patents that 
** you claim are infringed by the software, your patent license from such 
** contributor to the software ends automatically.
** (C) If you distribute any portion of the software, you must retain all 
** copyright, patent, trademark, and attribution notices that are present in 
** the software.
** (D) If you distribute any portion of the software in source code form, you 
** may do so only under this license by including a complete copy of this 
** license with your distribution. If you distribute any portion of the 
** software in compiled or object code form, you may only do so under a license
** that complies with this license.
** (E) The software is licensed "as-is." You bear the risk of using it. The 
** contributors give no express warranties, guarantees or conditions. You may 
** have additional consumer rights under your local laws which this license 
** cannot change. To the extent permitted under your local laws, the 
** contributors exclude the implied warranties of merchantability, fitness for 
** a particular purpose and non-infringement.
**
**==============================================================================
*/
/**
    \file
 
    \brief     Math helper functions
 
    \date      07-05-28 12:00:00
 

*/
/*----------------------------------------------------------------------------*/
#ifndef SCXMATH_H
#define SCXMATH_H

// Get the system definition of MIN/MAX to avoid future conflicts (only a problem on some HP:s)
#if defined(hpux)
#include <sys/param.h>
#endif /* hpux */

//! Classical mathematical MIN() function returning the smaller of two values
#ifndef MIN
#define MIN(a,b) ((a) < (b) ? (a) : (b))
#endif

//! Classical mathematical MAX() function returning the larger of two values
#ifndef MAX
#define MAX(a,b) ((a) > (b) ? (a) : (b))
#endif
   
namespace SCXCoreLib 
{
    scxulong GetPercentage(scxulong old_tic, scxulong new_tic, scxulong old_tot, scxulong new_tot, bool inverse=false);
    scxulong BytesToMegaBytes(scxulong bytes);
    double BytesToMegaBytes(double bytes);
    scxulong KiloBytesToMegaBytes(scxulong kiloBytes);
    double KiloBytesToMegaBytes(double kiloBytes);
    
    double Round(double value);
    scxlong RoundToScxLong(double value);
    signed int RoundToInt(double value);
    unsigned int RoundToUnsignedInt(double value);

    scxulong Abs(scxlong value);
    
    bool IsAscending(int value1, int value2, int value3);
    bool IsStrictlyAscending(int value1, int value2, int value3);
    
    scxlong Pow(scxlong base, scxulong exponent);
    
    signed int ToInt(scxlong value); 
    
    bool Equal(double value1, double value2, double precision);
}

#endif /* SCXMATH_H */
/*----------------------------E-N-D---O-F---F-I-L-E---------------------------*/
