/*
**==============================================================================
**
** Microsoft Public License (Ms-PL)
** 
** This license governs use of the accompanying software. If you use the 
** software, you accept this license. If you do not accept the license, do not 
** use the software.
**
** 1. Definitions
** The terms "reproduce," "reproduction," "derivative works," and 
** "distribution" have the same meaning here as under U.S. copyright law.
** A "contribution" is the original software, or any additions or changes to 
** the software.
** A "contributor" is any person that distributes its contribution under this 
** license.
** "Licensed patents" are a contributor's patent claims that read directly on 
** its contribution.
**
** 2. Grant of Rights
** (A) Copyright Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free copyright license to reproduce its
** contribution, prepare derivative works of its contribution, and distribute 
** its contribution or any derivative works that you create.
** (B) Patent Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free license under its licensed patents
** to make, have made, use, sell, offer for sale, import, and/or otherwise 
** dispose of its contribution in the software or derivative works of the 
** contribution in the software.
**
** 3. Conditions and Limitations
** (A) No Trademark License- This license does not grant you rights to use any 
** contributors' name, logo, or trademarks.
** (B) If you bring a patent claim against any contributor over patents that 
** you claim are infringed by the software, your patent license from such 
** contributor to the software ends automatically.
** (C) If you distribute any portion of the software, you must retain all 
** copyright, patent, trademark, and attribution notices that are present in 
** the software.
** (D) If you distribute any portion of the software in source code form, you 
** may do so only under this license by including a complete copy of this 
** license with your distribution. If you distribute any portion of the 
** software in compiled or object code form, you may only do so under a license
** that complies with this license.
** (E) The software is licensed "as-is." You bear the risk of using it. The 
** contributors give no express warranties, guarantees or conditions. You may 
** have additional consumer rights under your local laws which this license 
** cannot change. To the extent permitted under your local laws, the 
** contributors exclude the implied warranties of merchantability, fitness for 
** a particular purpose and non-infringement.
**
**==============================================================================
*/
/**
    \file
 
    \brief     Definition of SCXProviderLib::SCXCallContext
 
    \date      07-07-27 08:14:38
 
*/
/*----------------------------------------------------------------------------*/
#ifndef SCXPROVIDERCALLCTX_H
#define SCXPROVIDERCALLCTX_H


#include <scxproviderlib/scxprovidercapabilities.h>

namespace SCXProviderLib
{
    /*----------------------------------------------------------------------------*/
    /**
       Defines the call context information for providers inheriting from BaseProvider
    
       Providers which require more detailed information regarding the context 
       of a call will find the information in this class, provided in the Do\<Method\>()
       calls. Especially when a provider supports more than one class, it need to 
       decide the exact reason why the provider was called by the BaseProvider 
       functionality. That information is present in an object of this type. 
    
    */
    class SCXCallContext
    {
    public:
        /*----------------------------------------------------------------------------*/
        /**
           Ctor, used by the ProviderBase only
    
           \param       objectPath  The object path reason why this call was invoked
           \param       supportType The type of support the BaseProvider has discovered the Provider has
        */
        SCXCallContext(SCXInstance objectPath, SCXProviderSupportType supportType)
            : m_ObjectPath(objectPath), m_ProviderSupportType(supportType) {}

        //! Return the Object Path supplied by the client 
        const SCXInstance&      GetObjectPath() const { return m_ObjectPath; } 

        //! Return the type of support the provider has for the supplied Object Path
        SCXProviderSupportType  GetSupportType() const { return m_ProviderSupportType; }
        
    private:
        //! Container for the ObjectPath
        SCXInstance             m_ObjectPath;

        //! Container for the Provider support type information 
        SCXProviderSupportType  m_ProviderSupportType;

    };
}

#endif /* SCXPROVIDERCALLCTX_H */
/*----------------------------E-N-D---O-F---F-I-L-E---------------------------*/
