/*
**==============================================================================
**
** Microsoft Public License (Ms-PL)
** 
** This license governs use of the accompanying software. If you use the 
** software, you accept this license. If you do not accept the license, do not 
** use the software.
**
** 1. Definitions
** The terms "reproduce," "reproduction," "derivative works," and 
** "distribution" have the same meaning here as under U.S. copyright law.
** A "contribution" is the original software, or any additions or changes to 
** the software.
** A "contributor" is any person that distributes its contribution under this 
** license.
** "Licensed patents" are a contributor's patent claims that read directly on 
** its contribution.
**
** 2. Grant of Rights
** (A) Copyright Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free copyright license to reproduce its
** contribution, prepare derivative works of its contribution, and distribute 
** its contribution or any derivative works that you create.
** (B) Patent Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free license under its licensed patents
** to make, have made, use, sell, offer for sale, import, and/or otherwise 
** dispose of its contribution in the software or derivative works of the 
** contribution in the software.
**
** 3. Conditions and Limitations
** (A) No Trademark License- This license does not grant you rights to use any 
** contributors' name, logo, or trademarks.
** (B) If you bring a patent claim against any contributor over patents that 
** you claim are infringed by the software, your patent license from such 
** contributor to the software ends automatically.
** (C) If you distribute any portion of the software, you must retain all 
** copyright, patent, trademark, and attribution notices that are present in 
** the software.
** (D) If you distribute any portion of the software in source code form, you 
** may do so only under this license by including a complete copy of this 
** license with your distribution. If you distribute any portion of the 
** software in compiled or object code form, you may only do so under a license
** that complies with this license.
** (E) The software is licensed "as-is." You bear the risk of using it. The 
** contributors give no express warranties, guarantees or conditions. You may 
** have additional consumer rights under your local laws which this license 
** cannot change. To the extent permitted under your local laws, the 
** contributors exclude the implied warranties of merchantability, fitness for 
** a particular purpose and non-infringement.
**
**==============================================================================
*/
/**
    \file        

    \brief       Defines a class to parse lvmtab files.
    
    \date        2008-02-21 13:29:02

*/
/*----------------------------------------------------------------------------*/
#ifndef SCXLVMTAB_H
#define SCXLVMTAB_H
#include <scxcorelib/scxexception.h>
#include <scxcorelib/scxfilepath.h>
#include <vector>

namespace SCXSystemLib
{
/*----------------------------------------------------------------------------*/
/**
    Representation of a parsed lvmtab file
*/
    class SCXLvmTab
    {
    public:
        SCXLvmTab(const SCXCoreLib::SCXFilePath& path);

        size_t GetVGCount() const;
        size_t GetPartCount(size_t vg_idx) const;
        const std::wstring& GetVG(size_t vg_idx) const;
        const std::wstring& GetPart(size_t vg_idx, size_t part_idx) const;

    protected:
        SCXLvmTab() { } //!< Default constructor delibetrly made private 
        SCXLvmTab(const SCXLvmTab&); //!< Copy constructor delibetrly made private 
    
        //! A private representation of volume group information.
        struct SCXVG
        {
            std::wstring m_name; //!< Name of the volume group.
            std::vector<std::wstring> m_part; //!< Array of parts in volume group.
        };

        std::vector<SCXVG> m_vg; //!< List of volume groups.
    };

/*----------------------------------------------------------------------------*/
/**
   A generic exception for lvmtab format exceptions.
*/
    class SCXLvmTabFormatException: public SCXCoreLib::SCXException
    {
    public:
        /**
           Ctor
           \param[in] reason Description of format error
           \param[in] l      Source code location object

        */
        SCXLvmTabFormatException(const std::wstring& reason, const SCXCoreLib::SCXCodeLocation& l)
            : SCXCoreLib::SCXException(l), m_Reason(reason)
        { }
        
        std::wstring What() const {
            return L"Access violation exception was thrown because: " + m_Reason;
        }

    protected:
        //! Description of internal error
        std::wstring   m_Reason;

    };
} /* namespace SCXSystemLib */

#endif /* SCXLVMTAB_H */
/*----------------------------E-N-D---O-F---F-I-L-E---------------------------*/
