/*
**==============================================================================
**
** Microsoft Public License (Ms-PL)
** 
** This license governs use of the accompanying software. If you use the 
** software, you accept this license. If you do not accept the license, do not 
** use the software.
**
** 1. Definitions
** The terms "reproduce," "reproduction," "derivative works," and 
** "distribution" have the same meaning here as under U.S. copyright law.
** A "contribution" is the original software, or any additions or changes to 
** the software.
** A "contributor" is any person that distributes its contribution under this 
** license.
** "Licensed patents" are a contributor's patent claims that read directly on 
** its contribution.
**
** 2. Grant of Rights
** (A) Copyright Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free copyright license to reproduce its
** contribution, prepare derivative works of its contribution, and distribute 
** its contribution or any derivative works that you create.
** (B) Patent Grant- Subject to the terms of this license, including the 
** license conditions and limitations in section 3, each contributor grants you
** a non-exclusive, worldwide, royalty-free license under its licensed patents
** to make, have made, use, sell, offer for sale, import, and/or otherwise 
** dispose of its contribution in the software or derivative works of the 
** contribution in the software.
**
** 3. Conditions and Limitations
** (A) No Trademark License- This license does not grant you rights to use any 
** contributors' name, logo, or trademarks.
** (B) If you bring a patent claim against any contributor over patents that 
** you claim are infringed by the software, your patent license from such 
** contributor to the software ends automatically.
** (C) If you distribute any portion of the software, you must retain all 
** copyright, patent, trademark, and attribution notices that are present in 
** the software.
** (D) If you distribute any portion of the software in source code form, you 
** may do so only under this license by including a complete copy of this 
** license with your distribution. If you distribute any portion of the 
** software in compiled or object code form, you may only do so under a license
** that complies with this license.
** (E) The software is licensed "as-is." You bear the risk of using it. The 
** contributors give no express warranties, guarantees or conditions. You may 
** have additional consumer rights under your local laws which this license 
** cannot change. To the extent permitted under your local laws, the 
** contributors exclude the implied warranties of merchantability, fitness for 
** a particular purpose and non-infringement.
**
**==============================================================================
*/
/**
    \file

    \brief       Defines the static disk information instance PAL for physical disks.

    \date        2008-03-19 11:42:00

*/
/*----------------------------------------------------------------------------*/
#ifndef STATICPHYSICALDISKINSTANCE_H
#define STATICPHYSICALDISKINSTANCE_H

#include <scxsystemlib/entityinstance.h>
#include <scxsystemlib/diskdepend.h>
#include <scxcorelib/scxlog.h>
#include <scxcorelib/scxhandle.h>

#if defined(aix)

#include <odmi.h>

// Forward declaration
struct CuVPD;

#endif

namespace SCXSystemLib
{
/*----------------------------------------------------------------------------*/
/**
    Represents a single disk instance with static data.
*/
    class StaticPhysicalDiskInstance : public EntityInstance
    {
        friend class StaticPhysicalDiskEnumeration;

    public:
        StaticPhysicalDiskInstance(SCXCoreLib::SCXHandle<DiskDepend> deps);
        virtual ~StaticPhysicalDiskInstance();

        bool GetHealthState(bool& healthy) const;
        bool GetDiskName(std::wstring& value) const;
        bool GetDiskDevice(std::wstring& value) const;

        bool GetInterfaceType(DiskInterfaceType& value) const;
        bool GetManufacturer(std::wstring& value) const;
        bool GetModel(std::wstring& value) const;
        bool GetSizeInBytes(scxulong& value) const;
        bool GetTotalCylinders(scxulong& value) const;
        bool GetTotalHeads(scxulong& value) const;
        bool GetTotalSectors(scxulong& value) const;
        bool GetSectorSize(unsigned int& value) const;

        void SetDevice( const std::wstring& device ) {m_device = device;}

        virtual const std::wstring DumpString() const;
        virtual void Update();
        
        virtual void  SetUnexpectedException( const SCXCoreLib::SCXException& e );

    private:
        //! Private constructor (this should never be called!)
        StaticPhysicalDiskInstance();            //!< Default constructor (intentionally not implemented)

#if defined(aix)
        // Some AIX-specific routines to reduce complexity
        void DecodeVPD(const struct CuVPD *vpdItem);
        int LookupODM(CLASS_SYMBOL c, const std::wstring &criteria, void *pData);
#endif

        SCXCoreLib::SCXHandle<DiskDepend> m_deps;//!< StaticDiskDepend object
        SCXCoreLib::SCXLogHandle m_log;          //!< Log handle
        bool m_online;                           //!< Tells if disk is still connected.
        std::wstring m_device;                   //!< Device ID (i.e. /dev/sda)
        std::wstring m_rawDevice;                //!< Raw device name (internal use only)

        DiskInterfaceType m_intType;             //!< Interface type of device (IDE, SCSI, etc)
        std::wstring m_manufacturer;             //!< Disk drive manufacturer
        std::wstring m_model;                    //!< Disk drive model
        scxulong m_sizeInBytes;                  //!< Total size, in bytes
        scxulong m_totalCylinders;               //!< Total number of cylinders
        scxulong m_totalHeads;                   //!< Total number of heads
        scxulong m_totalSectors;                 //!< Total number of sectors
        unsigned int m_sectorSize;               //!< Sector size, in bytes
    };
} /* namespace SCXSystemLib */
#endif /* STATICPHYSICALDISKINSTANCE_H */
/*----------------------------E-N-D---O-F---F-I-L-E---------------------------*/
